﻿namespace TestProject
{
    /// <summary>
    /// GDI 텍스트 품질
    /// </summary>
    public enum GDITextQuality
    {
        /// <summary>
        /// SystemDefault
        /// </summary>
        /// <remarks>
        /// 각 문자는 시스템 기본 렌더링 힌트와 함께 해당 글리프 비트맵을 사용하여 그려집니다.
        /// 텍스트는 사용자가 시스템에 대해 선택한 글꼴 다듬기 설정을 사용하여 그려집니다.
        /// </remarks>
        SystemDefault,

        /// <summary>
        /// SingleBitPerPixelGridFit
        /// </summary>
        /// <remarks>
        /// 각 문자는 해당 글리프 비트맵을 사용하여 그려집니다.
        /// 힌팅은 줄기와 곡률의 문자 모양을 개선하는 데 사용됩니다.
        /// </remarks>
        SingleBitPerPixelGridFit,

        /// <summary>
        /// SingleBitPerPixel
        /// </summary>
        /// <remarks>
        /// 각 문자는 해당 글리프 비트맵을 사용하여 그려집니다.
        /// 힌트는 사용되지 않습니다.
        /// </remarks>
        SingleBitPerPixel,

        /// <summary>
        /// AntiAliasGridFit
        /// </summary>
        /// <remarks>
        /// 각 문자는 힌트가 있는 앤티앨리어싱된 글리프 비트맵을 사용하여 그려집니다.
        /// 앤티앨리어싱으로 인해 훨씬 더 나은 품질을 제공하지만 더 높은 성능 비용이 듭니다.
        /// </remarks>
        AntiAliasGridFit,

        /// <summary>
        /// AntiAlias
        /// </summary>
        /// <remarks>
        /// 각 문자는 힌트 없이 앤티앨리어싱된 글리프 비트맵을 사용하여 그려집니다.
        /// 앤티 앨리어싱으로 인해 더 나은 품질.
        /// 힌팅이 꺼져 있기 때문에 줄기 너비 차이가 눈에 띌 수 있습니다.
        /// </remarks>
        AntiAlias,

        /// <summary>
        /// ClearTypeGridFit
        /// </summary>
        /// <remarks>
        /// 각 문자는 힌트와 함께 해당 글리프 ClearType 비트맵을 사용하여 그려집니다.
        /// 최고 품질의 설정. ClearType 글꼴 기능을 활용하는 데 사용됩니다.
        /// </remarks>
        ClearTypeGridFit
    }
}